clear;
pkg load optim;

%filename definitions
series='3BUA-IP';
base=strcat(series,'-1-');
positionsfile=strcat(series,'-positions.csv');
heightsfile=strcat(series,'-heights.csv');
areasfile=strcat(series,'-areas.csv');
FWHMsfile=strcat(series,'-FWHMs.csv');
n=[0,1,2,3,4,6,10,15,100];%100 is pure solvent

%variables to store fitting results
spectrano=size(n)(2);
peaksno=20;
heights=zeros(spectrano+1,peaksno+1);
positions=zeros(spectrano+1,peaksno+1);
areas=zeros(spectrano+1,peaksno+1);
FWHMs=zeros(spectrano+1,peaksno+1);

%function definitions
pv=@(x,p) p(2)*exp(-(x-p(1)).^2/p(3))+p(2)./(1+(x-p(1)).^2/p(4).^2);%pseudo-voigt lineshape
%functions containing selected number of peaks
pv1=@(x,p) pv(x,p(1:4))+p(5)+x*p(6);
pv3=@(x,p) pv(x,p(1:4))+pv(x,p(5:8))+pv(x,p(9:12))+p(13)+x*p(14);
pv4=@(x,p) pv(x,p(1:4))+pv(x,p(5:8))+pv(x,p(9:12))+pv(x,p(13:16))+p(17)+x*p(18);
pv5=@(x,p) pv(x,p(1:4))+pv(x,p(5:8))+pv(x,p(9:12))+pv(x,p(13:16))+pv(x,p(17:20))+p(21)+x*p(22);
pv6=@(x,p) pv(x,p(1:4))+pv(x,p(5:8))+pv(x,p(9:12))+pv(x,p(13:16))+pv(x,p(17:20))+pv(x,p(21:24))+p(25)+x*p(26);
pv7=@(x,p) pv(x,p(1:4))+pv(x,p(5:8))+pv(x,p(9:12))+pv(x,p(13:16))+pv(x,p(17:20))+pv(x,p(21:24))+pv(x,p(25:28))+p(29)+x*p(30);
pv8=@(x,p) pv(x,p(1:4))+pv(x,p(5:8))+pv(x,p(9:12))+pv(x,p(13:16))+pv(x,p(17:20))+pv(x,p(21:24))+pv(x,p(25:28))+pv(x,p(29:32))+p(33)+x*p(34);

%the fitting cycle goes through the individual spectra and contains fitting selected spectral regions
for i=1:spectrano
%filename definitions
i
mtext=num2str(n(i));
basename=strcat(base,mtext);
spectrumfile=strcat(basename,'.CSV');
%uploading and measuring the data
spectrum=importdata(spectrumfile,';');
rws=rows(spectrum);
step=(spectrum(rws,1)-spectrum(1,1))/rws;

%region 1 - NH and OH stretching
from=3850; till=3120;%region definition
%cutting the spectral region from the uploaded spectrum
tillrow=round((from-(spectrum(1,1)))/step);
fromrow=round((till-(spectrum(1,1)))/step);
x=spectrum(fromrow:tillrow,1);
y=spectrum(fromrow:tillrow,2);
wt=ones(size(y));
%plot(x,y);

%specification of the fitting parameters in the structure x1=vlaue x of peak 1; x1b1= lower boud of x1; x1b2=upper bound of x1
%peak centers
c1=3340;c1b1=3300;c1b2=3400;
%c2=3460;c2b1=3450;c2b2=3470;

%peak height
h1=0.01;h1b1=0;h1b2=inf;
%h2=0;h2b1=0;h2b2=inf;

%width of the gaussian component
wg1=7000;wg1b1=5000;wg1b2=25000;
%wg2=500;wg2b1=200;wg2b2=5000;

%width of the lorentzian component
wl1=50;wl1b1=10;wl1b2=150;
%wl2=15;wl2b1=5;wl2b2=50;

%linear baseline
a=0.04;ab1=-inf;ab2=inf;
b=0;bb1=-1;bb2=1;

%reading up the fitting parameters
p=[c1,h1,wg1,wl1, a,b];
options.bounds=[c1b1,c1b2;h1b1,h1b2;wg1b1,wg1b2;wl1b1,wl1b2; ab1,ab2;bb1,bb2];
dp=0.001*ones(size(p));

%fitting and fit plotting
[yfit pfit]=leasqr(x,y,p,pv1,0.0001,20,wt,dp,'dfdp',options);
bs=pfit(5)+x*pfit(6);
p1=pv(x,pfit(1:4))+bs;
%p2=pv(x,pfit(5:8))+bs;
plot(x,y,x,yfit,x,p1,x,bs);
%saving of the plot
graphfile=strcat(num2str(i),"-",basename,"-1.jpg");
print(graphfile);

%saving of the fitted peak parameters, the cycle goes through peaks in the region
for r=1:1
  j=(r-1)*4;
  k=r;
  positions(i+1,k+1)=pfit(j+1);%positions
  heights(i+1,k+1)=2*pfit(j+2);%heights
  FWHMs(i+1,k+1)=0.5346*(pfit(j+4)*2)+sqrt(0.2166*(pfit(j+4)*2)+(2*sqrt(pfit(j+3)*log(2))).^2);
  areas(i+1,k+1)=sqrt(pi*log(2))*pfit(j+2)*pfit(j+3)+pi*pfit(j+2)*pfit(j+4);
endfor;

%region 2 - CH stretching
from=3100; till=2710;%region definition
%cutting the spectral region from the uploaded spectrum
tillrow=round((from-(spectrum(1,1)))/step);
fromrow=round((till-(spectrum(1,1)))/step);
x=spectrum(fromrow:tillrow,1);
y=spectrum(fromrow:tillrow,2);
wt=ones(size(y));
%plot(x,y);

%specification of the fitting parameters in the structure x1=vlaue x of peak 1; x1b1= lower boud of x1; x1b2=upper bound of x1
%peak centers
c1=2970;c1b1=2965;c1b2=2980;
c2=2956;c2b1=2950;c2b2=2960;
c3=2930;c3b1=2925;c3b2=2935;
c4=2895;c4b1=2890;c4b2=2920;
c5=2880;c5b1=2865;c5b2=2885;
c6=2862;c6b1=2855;c6b2=2868;

%peak height
h1=0;h1b1=0;h1b2=inf;
h2=0.01;h2b1=0;h2b2=inf;
h3=0.01;h3b1=0;h3b2=inf;
h4=0.01;h4b1=0;h4b2=inf;
h5=0.01;h5b1=0;h5b2=inf;
h6=0.01;h6b1=0;h6b2=inf;

%width of the gaussian component
wg1=50;wg1b1=10;wg1b2=700;
wg2=50;wg2b1=10;wg2b2=600;
wg3=50;wg3b1=20;wg3b2=600;
wg4=50;wg4b1=20;wg4b2=1000;
wg5=50;wg5b1=20;wg5b2=600;
wg6=50;wg6b1=20;wg6b2=600;

%width of the lorentzian component
wl1=20;wl1b1=10;wl1b2=500;
wl2=20;wl2b1=7;wl2b2=800;
wl3=20;wl3b1=10;wl3b2=700;
wl4=20;wl4b1=10;wl4b2=600;
wl5=20;wl5b1=7;wl5b2=700;
wl6=50;wl6b1=10;wl6b2=600;

%linear baseline
a=0;ab1=-inf;ab2=inf;
b=0;bb1=-1;bb2=1;

%reading up the fitting parameters
p=[c1,h1,wg1,wl1, c2,h2,wg2,wl2, c3,h3,wg3,wl3, c4,h4,wg4,wl4, c5,h5,wg5,wl5, c6,h6,wg6,wl6, a,b];
options.bounds=[c1b1,c1b2;h1b1,h1b2;wg1b1,wg1b2;wl1b1,wl1b2; c2b1,c2b2;h2b1,h2b2;wg2b1,wg2b2;wl2b1,wl2b2; c3b1,c3b2;h3b1,h3b2;wg3b1,wg3b2;wl3b1,wl3; c4b1,c4b2;h4b1,h4b2;wg4b1,wg4b2;wl4b1,wl4b2; c5b1,c5b2;h5b1,h5b2;wg5b1,wg5b2;wl5b1,wl5b2; c6b1,c6b2;h6b1,h6b2;wg6b1,wg6b2;wl6b1,wl6b2; ab1,ab2;bb1,bb2];
dp=0.001*ones(size(p));

%fitting and fit plotting
[yfit pfit]=leasqr(x,y,p,pv6,0.0001,20,wt,dp,'dfdp',options);
bs=pfit(25)+x*pfit(26);
p1=pv(x,pfit(1:4))+bs;
p2=pv(x,pfit(5:8))+bs;
p3=pv(x,pfit(9:12))+bs;
p4=pv(x,pfit(13:16))+bs;
p5=pv(x,pfit(17:20))+bs;
p6=pv(x,pfit(21:24))+bs;
plot(x,y,x,yfit,x,p1,x,p2,x,p3,x,p4,x,p5,x,p6,x,bs);
%saving of the plot
graphfile=strcat(num2str(i),"-",basename,"-2.jpg");
print(graphfile);

%saving of the fitted peak parameters, the cycle goes through peaks in the region
for r=1:6
  j=(r-1)*4;
  k=r+1;
  positions(i+1,k+1)=pfit(j+1);%positions
  heights(i+1,k+1)=2*pfit(j+2);%heights
  FWHMs(i+1,k+1)=0.5346*(pfit(j+4)*2)+sqrt(0.2166*(pfit(j+4)*2)+(2*sqrt(pfit(j+3)*log(2))).^2);
  areas(i+1,k+1)=sqrt(pi*log(2))*pfit(j+2)*pfit(j+3)+pi*pfit(j+2)*pfit(j+4);
endfor;

%region 3 - carbonyl stretching
from=1800; till=1580;%region definition
%cutting the spectral region from the uploaded spectrum
tillrow=round((from-(spectrum(1,1)))/step);
fromrow=round((till-(spectrum(1,1)))/step);
x=spectrum(fromrow:tillrow,1);
y=spectrum(fromrow:tillrow,2);
wt=ones(size(y));
%plot(x,y);

%specification of the fitting parameters in the structure x1=vlaue x of peak 1; x1b1= lower boud of x1; x1b2=upper bound of x1
%peak centers
c1=1767;c1b1=1760;c1b2=1770;
c2=1715;c2b1=1710;c2b2=1720;
c3=1695;c3b1=1690;c3b2=1700;
c4=1655;c4b1=1650;c4b2=1680;
c5=1627;c5b1=1615;c5b2=1638;
c6=1600;c6b1=1590;c6b2=1610;

%peak height
h1=0;h1b1=0;h1b2=inf;
h2=0;h2b1=0;h2b2=inf;
h3=0;h3b1=0;h3b2=inf;
h4=0.005;h4b1=0;h4b2=inf;
h5=0.02;h5b1=0;h5b2=inf;
h6=0.005;h6b1=0;h6b2=inf;

%width of the gaussian component
wg1=100;wg1b1=25;wg1b2=200;
wg2=100;wg2b1=20;wg2b2=300;
wg3=150;wg3b1=20;wg3b2=500;
wg4=800;wg4b1=20;wg4b2=1000;
wg5=150;wg5b1=10;wg5b2=600;
wg6=150;wg6b1=10;wg6b2=1000;

%width of the lorentzian component
wl1=10;wl1b1=5;wl1b2=15;
wl2=10;wl2b1=5;wl2b2=15;
wl3=15;wl3b1=5;wl3b2=20;
wl4=10;wl4b1=5;wl4b2=25;
wl5=10;wl5b1=5;wl5b2=25;
wl6=15;wl6b1=5;wl6b2=35;

%linear baseline
a=-0.01;ab1=-inf;ab2=inf;
b=0;bb1=-1;bb2=1;

%reading up the fitting parameters
p=[c1,h1,wg1,wl1, c2,h2,wg2,wl2, c3,h3,wg3,wl3, c4,h4,wg4,wl4, c5,h5,wg5,wl5, c6,h6,wg6,wl6, a,b];
options.bounds=[c1b1,c1b2;h1b1,h1b2;wg1b1,wg1b2;wl1b1,wl1b2; c2b1,c2b2;h2b1,h2b2;wg2b1,wg2b2;wl2b1,wl2b2; c3b1,c3b2;h3b1,h3b2;wg3b1,wg3b2;wl3b1,wl3; c4b1,c4b2;h4b1,h4b2;wg4b1,wg4b2;wl4b1,wl4b2; c5b1,c5b2;h5b1,h5b2;wg5b1,wg5b2;wl5b1,wl5b2; c6b1,c6b2;h6b1,h6b2;wg6b1,wg6b2;wl6b1,wl6b2; ab1,ab2;bb1,bb2];
dp=0.001*ones(size(p));

%fitting and fit plotting
[yfit pfit]=leasqr(x,y,p,pv6,0.0001,20,wt,dp,'dfdp',options);
bs=pfit(25)+x*pfit(26);
p1=pv(x,pfit(1:4))+bs;
p2=pv(x,pfit(5:8))+bs;
p3=pv(x,pfit(9:12))+bs;
p4=pv(x,pfit(13:16))+bs;
p5=pv(x,pfit(17:20))+bs;
p6=pv(x,pfit(21:24))+bs;
plot(x,y,x,yfit,x,p1,x,p2,x,p3,x,p4,x,p5,x,p6,x,bs);
%saving of the plot
graphfile=strcat(num2str(i),"-",basename,"-3.jpg");
print(graphfile);

%saving of the fitted peak parameters, the cycle goes through peaks in the region
for r=1:6
  j=(r-1)*4;
  k=r+7;
  positions(i+1,k+1)=pfit(j+1);%positions
  heights(i+1,k+1)=2*pfit(j+2);%heights
  FWHMs(i+1,k+1)=0.5346*(pfit(j+4)*2)+sqrt(0.2166*(pfit(j+4)*2)+(2*sqrt(pfit(j+3)*log(2))).^2);
  areas(i+1,k+1)=sqrt(pi*log(2))*pfit(j+2)*pfit(j+3)+pi*pfit(j+2)*pfit(j+4);
endfor;

%region 4 - amide II
from=1580; till=1505; %region definition
%cutting the spectral region from the uploaded spectrum
tillrow=round((from-(spectrum(1,1)))/step);
fromrow=round((till-(spectrum(1,1)))/step);
x=spectrum(fromrow:tillrow,1);
y=spectrum(fromrow:tillrow,2);
wt=ones(size(y));
%plot(x,y);

%specification of the fitting parameters in the structure x1=vlaue x of peak 1; x1b1= lower boud of x1; x1b2=upper bound of x1
%peak centers
c1=1530;c1b1=1520;c1b2=1550;

%peak height
h1=0.01;h1b1=0;h1b2=inf;

%width of the gaussian component
wg1=50;wg1b1=30;wg1b2=5000;

%width of the lorentzian component
wl1=7;wl1b1=3;wl1b2=50;

%linear baseline
a=0;ab1=-inf;ab2=inf;
b=0;bb1=-1;bb2=1;

%reading up the fitting parameters
p=[c1,h1,wg1,wl1, a,b];
options.bounds=[c1b1,c1b2;h1b1,h1b2;wg1b1,wg1b2;wl1b1,wl1b2; ab1,ab2;bb1,bb2];
dp=0.001*ones(size(p));

%fitting and fit plotting
[yfit pfit]=leasqr(x,y,p,pv1,0.0001,20,wt,dp,'dfdp',options);
bs=pfit(5)+x*pfit(6);
p1=pv(x,pfit(1:4))+bs;
plot(x,y,x,yfit,x,p1,x,bs);
%saving of the plot
graphfile=strcat(num2str(i),"-",basename,"-4.jpg");
print(graphfile);

%saving of the fitted peak parameters, the cycle goes through peaks in the region
for r=1:1
  j=(r-1)*4;
  k=r+13;
  positions(i+1,k+1)=pfit(j+1);%positions
  heights(i+1,k+1)=2*pfit(j+2);%heights
  FWHMs(i+1,k+1)=0.5346*(pfit(j+4)*2)+sqrt(0.2166*(pfit(j+4)*2)+(2*sqrt(pfit(j+3)*log(2))).^2);
  areas(i+1,k+1)=sqrt(pi*log(2))*pfit(j+2)*pfit(j+3)+pi*pfit(j+2)*pfit(j+4);
endfor;

%region 5 - alcohol C-O stretching
from=1275; till=1181; %region definition
%cutting the spectral region from the uploaded spectrum
tillrow=round((from-(spectrum(1,1)))/step);
fromrow=round((till-(spectrum(1,1)))/step);
x=spectrum(fromrow:tillrow,1);
y=spectrum(fromrow:tillrow,2);
wt=ones(size(y));
%plot(x,y);

%specification of the fitting parameters in the structure x1=vlaue x of peak 1; x1b1= lower boud of x1; x1b2=upper bound of x1
%peak centers
c1=1290;c1b1=1270;c1b2=1350;%band in neighboring region creating baseline
c2=1260;c2b1=1250;c2b2=1270;
c3=1235;c3b1=1230;c3b2=1240;
c4=1222;c4b1=1215;c4b2=1230;
c5=1200;c5b1=1195;c5b2=1205;
c6=1190;c6b1=1180;c6b2=1195;

%peak height
h1=0.01;h1b1=0.0005;h1b2=inf;
h2=0;h2b1=0;h2b2=inf;
h3=0;h3b1=0;h3b2=inf;
h4=0;h4b1=0;h4b2=inf;
h5=0;h5b1=0;h5b2=inf;
h6=0.01;h6b1=0;h6b2=inf;

%width of the gaussian component
wg1=1000;wg1b1=300;wg1b2=2000;
wg2=50;wg2b1=10;wg2b2=1000;
wg3=50;wg3b1=10;wg3b2=600;
wg4=50;wg4b1=20;wg4b2=600;
wg5=50;wg5b1=10;wg5b2=600;
wg6=150;wg6b1=10;wg6b2=500;

%width of the lorentzian component
wl1=20;wl1b1=5;wl1b2=30;
wl2=20;wl2b1=5;wl2b2=80;
wl3=20;wl3b1=5;wl3b2=70;
wl4=10;wl4b1=5;wl4b2=60;
wl5=10;wl5b1=3;wl5b2=30;
wl6=10;wl6b1=3;wl6b2=25;

%linear baseline
a=0.03;ab1=-inf;ab2=inf;
b=0;bb1=-1;bb2=1;

%reading up the fitting parameters
p=[c1,h1,wg1,wl1, c2,h2,wg2,wl2, c3,h3,wg3,wl3, c4,h4,wg4,wl4, c5,h5,wg5,wl5, c6,h6,wg6,wl6, a,b];
options.bounds=[c1b1,c1b2;h1b1,h1b2;wg1b1,wg1b2;wl1b1,wl1b2; c2b1,c2b2;h2b1,h2b2;wg2b1,wg2b2;wl2b1,wl2b2; c3b1,c3b2;h3b1,h3b2;wg3b1,wg3b2;wl3b1,wl3; c4b1,c4b2;h4b1,h4b2;wg4b1,wg4b2;wl4b1,wl4b2; c5b1,c5b2;h5b1,h5b2;wg5b1,wg5b2;wl5b1,wl5b2; c6b1,c6b2;h6b1,h6b2;wg6b1,wg6b2;wl6b1,wl6b2; ab1,ab2;bb1,bb2];
dp=0.001*ones(size(p));

%fitting and fit plotting
[yfit pfit]=leasqr(x,y,p,pv6,0.0001,20,wt,dp,'dfdp',options);
bs=pfit(25)+x*pfit(26);
p1=pv(x,pfit(1:4))+bs;
p2=pv(x,pfit(5:8))+bs;
p3=pv(x,pfit(9:12))+bs;
p4=pv(x,pfit(13:16))+bs;
p5=pv(x,pfit(17:20))+bs;
p6=pv(x,pfit(21:24))+bs;
plot(x,y,x,yfit,x,p1,x,p2,x,p3,x,p4,x,p5,x,p6,x,bs);
%saving of the plot
graphfile=strcat(num2str(i),"-",basename,"-5.jpg");
print(graphfile);

%saving of the fitted peak parameters, the cycle goes through peaks in the region
for r=1:6
  j=(r-1)*4;
  k=r+14;
  positions(i+1,k+1)=pfit(j+1);%positions
  heights(i+1,k+1)=2*pfit(j+2);%heights
  FWHMs(i+1,k+1)=0.5346*(pfit(j+4)*2)+sqrt(0.2166*(pfit(j+4)*2)+(2*sqrt(pfit(j+3)*log(2))).^2);
  areas(i+1,k+1)=sqrt(pi*log(2))*pfit(j+2)*pfit(j+3)+pi*pfit(j+2)*pfit(j+4);
endfor;

%region 6 - urea skeletals
from=840; till=690;%region definition
%cutting the spectral region from the uploaded spectrum
tillrow=round((from-(spectrum(1,1)))/step);
fromrow=round((till-(spectrum(1,1)))/step);
x=spectrum(fromrow:tillrow,1);
y=spectrum(fromrow:tillrow,2);
wt=ones(size(y));
%plot(x,y);

%specification of the fitting parameters in the structure x1=vlaue x of peak 1; x1b1= lower boud of x1; x1b2=upper bound of x1
%peak centers
c1=810;c1b1=800;c1b2=830;
c2=785;c2b1=780;c2b2=805;
c3=767;c3b1=760;c3b2=775;
c4=743;c4b1=738;c4b2=750;
c5=732;c5b1=725;c5b2=738;

%peak height
h1=0.01;h1b1=0;h1b2=inf;
h2=0.01;h2b1=0;h2b2=inf;
h3=0.01;h3b1=0;h3b2=inf;
h4=0.01;h4b1=0;h4b2=inf;
h5=0.01;h5b1=0;h5b2=inf;

%width of the gaussian component
wg1=50;wg1b1=10;wg1b2=700;
wg2=50;wg2b1=10;wg2b2=600;
wg3=50;wg3b1=20;wg3b2=600;
wg4=50;wg4b1=20;wg4b2=600;
wg5=50;wg5b1=10;wg5b2=600;

%width of the lorentzian component
wl1=20;wl1b1=5;wl1b2=30;
wl2=20;wl2b1=5;wl2b2=80;
wl3=20;wl3b1=5;wl3b2=70;
wl4=10;wl4b1=5;wl4b2=60;
wl5=10;wl5b1=3;wl5b2=30;

%linear baseline
a=0;ab1=-inf;ab2=inf;
b=0;bb1=-1;bb2=1;

%reading up the fitting parameters
p=[c1,h1,wg1,wl1, c2,h2,wg2,wl2, c3,h3,wg3,wl3, c4,h4,wg4,wl4, c5,h5,wg5,wl5, a,b];
options.bounds=[c1b1,c1b2;h1b1,h1b2;wg1b1,wg1b2;wl1b1,wl1b2; c2b1,c2b2;h2b1,h2b2;wg2b1,wg2b2;wl2b1,wl2b2; c3b1,c3b2;h3b1,h3b2;wg3b1,wg3b2;wl3b1,wl3; c4b1,c4b2;h4b1,h4b2;wg4b1,wg4b2;wl4b1,wl4b2; c5b1,c5b2;h5b1,h5b2;wg5b1,wg5b2;wl5b1,wl5b2; ab1,ab2;bb1,bb2];
dp=0.001*ones(size(p));

%fitting and fit plotting
[yfit pfit]=leasqr(x,y,p,pv5,0.0001,20,wt,dp,'dfdp',options);
bs=pfit(21)+x*pfit(22);
p1=pv(x,pfit(1:4))+bs;
p2=pv(x,pfit(5:8))+bs;
p3=pv(x,pfit(9:12))+bs;
p4=pv(x,pfit(13:16))+bs;
p5=pv(x,pfit(17:20))+bs;
plot(x,y,x,yfit,x,p1,x,p2,x,p3,x,p4,x,p5,x,bs);
%saving of the plot
graphfile=strcat(num2str(i),"-",basename,"-6.jpg");
print(graphfile);

%saving of the fitted peak parameters, the cycle goes through peaks in the region
for r=1:5
  j=(r-1)*4;
  k=r+20;
  positions(i+1,k+1)=pfit(j+1);%positions
  heights(i+1,k+1)=2*pfit(j+2);%heights
  FWHMs(i+1,k+1)=0.5346*(pfit(j+4)*2)+sqrt(0.2166*(pfit(j+4)*2)+(2*sqrt(pfit(j+3)*log(2))).^2);
  areas(i+1,k+1)=sqrt(pi*log(2))*pfit(j+2)*pfit(j+3)+pi*pfit(j+2)*pfit(j+4);
endfor;


%line lables of the saved results are based on the dilution
positions(i+1,1)=n(i);
heights(i+1,1)=n(i);
areas(i+1,1)=n(i);
FWHMs(i+1,1)=n(i);

endfor;

%column labels of the saved data are the average peak positions
for m=1:peaksno
  possum=0;
  for i=1:spectrano
    possum=possum+positions(i+1,m+1);
  endfor;
  peaklabel=round(possum/spectrano);
  positions(1,m+1)=peaklabel;
  heights(1,m+1)=peaklabel;
  areas(1,m+1)=peaklabel;
  FWHMs(1,m+1)=peaklabel;
endfor;

%saving the fit results variables to files
save("-text",positionsfile,'positions');
save("-text",heightsfile,'heights');
save("-text",areasfile,'areas');
save("-text",FWHMsfile,'FWHMs');
